# geoapis

![Linux](https://github.com/niwa/geoapis/actions/workflows/linux-test.yml/badge.svg)

**_geoapis_** is a Python package for simply downloading publicly available web-hosted geo-spatial data. It currently supports downloading LiDAR data from OpenTopography, and vector data from the LINZ Data Service.

## Installation
**_geoapis_** is avaliable on [conda-forge](https://anaconda.org/conda-forge/geoapis) and [PyPI](https://pypi.org/project/geoapis/). Conda is recommended due to difficulties installing geopandas (a dependency) with pip on Windows. See the [Wiki Install Instructions](https://github.com/niwa/geoapis/wiki/Package-Install-Instructions) for more information.

## Documentation
Package API documentation is hosted at https://rosepearson.github.io/GeoFabrics/. Usage, installation and testing documentation can be found at the [GitHub Wiki](https://github.com/niwa/geoapis/wiki).

### Development
Please see the [issues](https://github.com/niwa/geoapis/issues) for details on coming features and additions to the software. Please also submit any requests for new functionality here.

### Contributions
There is no current expectations of contributions to this project. We accept input in code reviews now. If you would like to be involved in the project, please contact the maintainer.

### Contacts
Maintainer: Rose Pearson @rosepearson rose.pearson@niwa.co.nz

## License
[MIT](https://github.com/rosepearson/geoapis/LICENSE)
